import axios from "axios";
import { S3, CloudFront } from "aws-sdk";
const s3 = new S3({ apiVersion: "2006-03-01" });
const cloudfront = new CloudFront({ apiVersion: "2020-05-31" });
const handler = async function () {
    // Gets repo structure from github
    const res = await axios.get("https://api.github.com/repos/GovTechSG/dev-console-products-info/git/trees/main");
    // Extract only json files
    const filePaths = res.data.tree.filter((item) => item.path.includes(".json"));
    let blobResList = await Promise.all(filePaths.map((file) => axios
        .get(file.url)
        .then((res) => ({ path: file.path, content: res.data.content }))));
    async function emptyS3Directory(bucket, dir) {
        var _a, _b;
        const listParams = {
            Bucket: bucket,
            Prefix: dir,
        };
        const listedObjects = await s3.listObjectsV2(listParams).promise();
        if (((_a = listedObjects === null || listedObjects === void 0 ? void 0 : listedObjects.Contents) === null || _a === void 0 ? void 0 : _a.length) === 0)
            return;
        const deleteParams = {
            Bucket: bucket,
            Delete: { Objects: [] },
        };
        (_b = listedObjects === null || listedObjects === void 0 ? void 0 : listedObjects.Contents) === null || _b === void 0 ? void 0 : _b.forEach(({ Key }) => {
            deleteParams.Delete.Objects.push({ Key });
        });
        await s3.deleteObjects(deleteParams).promise();
        if (listedObjects.IsTruncated)
            await emptyS3Directory(bucket, dir);
    }
    // Default deletion with recursion
    await emptyS3Directory("dev-console-widget-test", "products-details/");
    // Upload new files to s3
    await Promise.all(blobResList.map(async (file) => {
        let fileBuffer = Buffer.from(file.content, "base64");
        let s3UploadParams = {
            Bucket: "dev-console-widget-test",
            Key: `products-details/${file.path}`,
            Body: fileBuffer,
        };
        return new Promise((resolve, reject) => {
            s3.upload(s3UploadParams, (err, data) => {
                if (err) {
                    return reject(err);
                }
                resolve(data);
            });
        });
    }));
    // Invalidate cloudfront cache
    const currentDate = new Date();
    const timestamp = currentDate.getTime().toString();
    const params = {
        DistributionId: "E2CY2A0UJXPD9W" /* required */,
        InvalidationBatch: {
            /* required */ CallerReference: timestamp /* required */,
            Paths: {
                /* required */ Quantity: 1 /* required */,
                Items: ["/*"],
            },
        },
    };
    await cloudfront.createInvalidation(params).promise();
};
export { handler };
//# sourceMappingURL=products-info-handler.js.map